"use strict";

exports.__esModule = true;
exports.registerBeforeUnloadHandler = void 0;
const registerBeforeUnloadHandler = channel => {
  const eventTarget = new EventTarget();
  const isInWorker = typeof window === 'undefined';
  const onIframeBeforeUnload = event => {
    const shouldUnloadWithoutConfirmation = eventTarget.dispatchEvent(new CustomEvent('beforeunload', {
      cancelable: true
    }));
    if (!shouldUnloadWithoutConfirmation) {
      event.preventDefault();
      event.returnValue = true; // Chrome requires returnValue to be set
    }
  };
  const onBeforeUnloadHandle = channel.onBeforeUnload(onIframeBeforeUnload);
  const clearBeforeUnloadHandler = () => {
    if (!isInWorker) {
      window.removeEventListener('beforeunload', onIframeBeforeUnload);
    }
    onBeforeUnloadHandle.then(({
      remove
    }) => remove());
  };
  if (!isInWorker) {
    window.addEventListener('beforeunload', onIframeBeforeUnload);
    window.addEventListener('unload', clearBeforeUnloadHandler);
  }
  const onBeforeUnload = callback => {
    eventTarget.addEventListener('beforeunload', callback);
    const remove = () => {
      eventTarget.removeEventListener('beforeunload', callback);
    };
    return {
      remove
    };
  };
  return {
    onBeforeUnload,
    clearBeforeUnloadHandler
  };
};
exports.registerBeforeUnloadHandler = registerBeforeUnloadHandler;
//# sourceMappingURL=registerOnBeforeUnload.js.map