"use strict";

exports.__esModule = true;
exports.createSDKBuilders = void 0;
var _addSitePlugin = require("./types/addSitePlugin");
const createSDKBuilders = () => {
  const showToast = ({
    channel
  }) => (...args) => {
    const handle = channel.showToast(...args);
    const remove = () => Promise.resolve(handle).then(h => h.remove());
    return {
      remove
    };
  };
  const observeState = ({
    channel
  }) => (...args) => {
    const handle = channel.observeState(...args); // this temporary casting is needed because it seems that typescript can't handle this by itself.
    const disconnect = () => Promise.resolve(handle).then(h => h.disconnect());
    return {
      disconnect
    };
  };
  const navigate = ({
    channel
  }) => (...args) => {
    return channel.navigate(...args);
  };
  const navigateBack = ({
    channel
  }) => () => {
    return channel.navigateBack();
  };
  const openModal = ({
    channel
  }) => (modalInfo, modalParams) => {
    const [modalId, params] = typeof modalInfo === 'string' ? [modalInfo, modalParams] : [modalInfo.modalId, modalInfo.params];
    const handle = channel.openModal(modalId, params);
    return {
      modalClosed: Promise.resolve(handle).then(h => h.modalClosed)
    };
  };
  const closeModal = ({
    channel
  }) => closeData => {
    if (closeData === undefined) {
      return channel.closeModal();
    }
    const filteredArg = JSON.parse(JSON.stringify(closeData));
    return channel.closeModal(filteredArg);
  };
  const getAccessToken = ({
    channel
  }) => () => {
    return channel.getAccessToken();
  };
  const getPageUrl = ({
    channel
  }) => (...args) => {
    return channel.getPageUrl(...args);
  };
  const openMediaManager = ({
    channel
  }) => (...args) => {
    return channel.openMediaManager(...args);
  };
  const addSitePlugin = ({
    channel
  }) => (pluginId, options) => {
    const PLUGINS_DASHBOARD_MODAL_ID = '802c76e4-b381-4bb3-9152-96acabbf3194';
    const additionalParams = (options == null ? void 0 : options.placement) || {};
    const handle = channel.openModal(PLUGINS_DASHBOARD_MODAL_ID, {
      ...additionalParams,
      pluginId,
      action: 'populate'
    });
    return Promise.resolve(handle).then(h => h.modalClosed).then(resp => {
      if ((resp == null ? void 0 : resp.type) === undefined) {
        throw new _addSitePlugin.AddSitePluginModalError({
          message: 'Aborted by user',
          code: 3006
        });
      }
      if ((resp == null ? void 0 : resp.type) === 'ERROR') {
        throw new _addSitePlugin.AddSitePluginModalError(resp.data.error);
      }
    });
  };
  const onBeforeUnload = ({
    channel
  }) => (...args) => {
    return channel.onBeforeUnload(...args);
  };
  const setPageTitle = ({
    channel
  }) => pageTitle => {
    return channel.setPageTitle(pageTitle);
  };
  const getLanguage = host => {
    let language = null;
    return async () => {
      var _observeStateResult;
      if (language) {
        return language;
      }
      let observeStateResult = null;
      language = await new Promise(resolve => {
        observeStateResult = observeState(host)((_, envState) => {
          resolve(envState.language);
        });
      });
      (_observeStateResult = observeStateResult) == null || _observeStateResult.disconnect();
      return language;
    };
  };
  const requestFeedback = ({
    channel
  }) => (...args) => {
    return channel.requestFeedback(...args);
  };
  const onLayerStateChange = ({
    channel
  }) => (...args) => {
    const resultOrPromise = channel.onLayerStateChange(...args);
    const remove = () => Promise.resolve(resultOrPromise).then(h => h.remove());
    return {
      remove
    };
  };
  const installApp = ({
    channel
  }) => channel.installApp;
  const getWidget = ({
    channel
  }) => (...args) => {
    if ('getWidget' in channel) {
      return channel.getWidget(...args);
    } else {
      throw new Error('Unsupported');
    }
  };
  const getDashboardPlugins = ({
    channel
  }) => (...args) => {
    if ('getDashboardPlugins' in channel) {
      return channel.getDashboardPlugins(...args);
    } else {
      throw new Error('Unsupported');
    }
  };
  const getDashboardMenuPlugins = ({
    channel
  }) => (...args) => {
    if ('getDashboardMenuPlugins' in channel) {
      return channel.getDashboardMenuPlugins(...args);
    } else {
      throw new Error('Unsupported');
    }
  };
  const getSiteInfo = ({
    channel
  }) => channel.getSiteInfo;
  return {
    showToast,
    observeState,
    navigate,
    navigateBack,
    openModal,
    closeModal,
    getAccessToken,
    getPageUrl,
    openMediaManager,
    addSitePlugin,
    onBeforeUnload,
    setPageTitle,
    getLanguage,
    requestFeedback,
    onLayerStateChange,
    installApp,
    getSiteInfo,
    getWidget,
    getDashboardPlugins,
    getDashboardMenuPlugins
  };
};
exports.createSDKBuilders = createSDKBuilders;
//# sourceMappingURL=sdk.js.map