import _extends from "@babel/runtime/helpers/extends";
// eslint-disable-next-line import/no-extraneous-dependencies
import React, { useEffect, useState } from 'react';
// eslint-disable-next-line import/no-extraneous-dependencies
import { createClient } from '@wix/sdk';
import { dashboard } from './index';
const useBeforeRenderEffect = (effect, effectCondition) => {
  const [lastEffectResult, setState] = useState(() => effect());
  if (effectCondition(lastEffectResult)) {
    setState(effect());
  }
  return lastEffectResult;
};
export const withContextualWixClient = Component => {
  return ownPropsWithHost => {
    const {
      host,
      compProps
    } = useHostAndProps(ownPropsWithHost);
    useBeforeRenderEffect(() => {
      createClient({
        auth: dashboard.auth(),
        host
      }).enableContext('module');
      return host;
    }, lastHost => lastHost !== host);
    return compProps ? /*#__PURE__*/React.createElement(Component, _extends({
      host: host
    }, compProps)) : null;
  };
};
const useHostAndProps = ownPropsWithHost => {
  const {
    host: maybeLocalHost,
    ...ownProps
  } = ownPropsWithHost;
  const {
    host,
    hostType
  } = useBeforeRenderEffect(() => maybeLocalHost ? {
    host: maybeLocalHost,
    hostType: 'local'
  } : {
    host: dashboard.host(),
    hostType: 'remote'
  }, lastResult => !!maybeLocalHost && maybeLocalHost !== lastResult.host);
  const [hostProps, setHostProps] = useState(undefined);
  useEffect(() => {
    if (hostType === 'local') {
      return;
    }
    const observeResult = host.channel.observeState(newPropsFromHost => {
      setHostProps(newPropsFromHost || {});
    });
    const cleanup = async () => {
      (await observeResult).disconnect();
      host.close();
    };
    return () => {
      cleanup();
    };
  }, [host, hostType]);
  return hostType === 'local' ? {
    host,
    compProps: ownProps
  } : {
    host,
    compProps: hostProps ? {
      ...hostProps,
      ...ownProps
    } : undefined
  };
};
//# sourceMappingURL=internal.js.map