import { AddSitePluginModalError } from './types/addSitePlugin';
export const createSDKBuilders = () => {
  const showToast = _ref => {
    let {
      channel
    } = _ref;
    return function () {
      const handle = channel.showToast(...arguments);
      const remove = () => Promise.resolve(handle).then(h => h.remove());
      return {
        remove
      };
    };
  };
  const observeState = _ref2 => {
    let {
      channel
    } = _ref2;
    return function () {
      const handle = channel.observeState(...arguments); // this temporary casting is needed because it seems that typescript can't handle this by itself.
      const disconnect = () => Promise.resolve(handle).then(h => h.disconnect());
      return {
        disconnect
      };
    };
  };
  const navigate = _ref3 => {
    let {
      channel
    } = _ref3;
    return function () {
      return channel.navigate(...arguments);
    };
  };
  const navigateBack = _ref4 => {
    let {
      channel
    } = _ref4;
    return () => {
      return channel.navigateBack();
    };
  };
  const openModal = _ref5 => {
    let {
      channel
    } = _ref5;
    return (modalInfo, modalParams) => {
      const [modalId, params] = typeof modalInfo === 'string' ? [modalInfo, modalParams] : [modalInfo.modalId, modalInfo.params];
      const handle = channel.openModal(modalId, params);
      return {
        modalClosed: Promise.resolve(handle).then(h => h.modalClosed)
      };
    };
  };
  const closeModal = _ref6 => {
    let {
      channel
    } = _ref6;
    return closeData => {
      if (closeData === undefined) {
        return channel.closeModal();
      }
      const filteredArg = JSON.parse(JSON.stringify(closeData));
      return channel.closeModal(filteredArg);
    };
  };
  const getAccessToken = _ref7 => {
    let {
      channel
    } = _ref7;
    return () => {
      return channel.getAccessToken();
    };
  };
  const getPageUrl = _ref8 => {
    let {
      channel
    } = _ref8;
    return function () {
      return channel.getPageUrl(...arguments);
    };
  };
  const openMediaManager = _ref9 => {
    let {
      channel
    } = _ref9;
    return function () {
      return channel.openMediaManager(...arguments);
    };
  };
  const addSitePlugin = _ref10 => {
    let {
      channel
    } = _ref10;
    return (pluginId, options) => {
      const PLUGINS_DASHBOARD_MODAL_ID = '802c76e4-b381-4bb3-9152-96acabbf3194';
      const additionalParams = (options == null ? void 0 : options.placement) || {};
      const handle = channel.openModal(PLUGINS_DASHBOARD_MODAL_ID, {
        ...additionalParams,
        pluginId,
        action: 'populate'
      });
      return Promise.resolve(handle).then(h => h.modalClosed).then(resp => {
        if ((resp == null ? void 0 : resp.type) === undefined) {
          throw new AddSitePluginModalError({
            message: 'Aborted by user',
            code: 3006
          });
        }
        if ((resp == null ? void 0 : resp.type) === 'ERROR') {
          throw new AddSitePluginModalError(resp.data.error);
        }
      });
    };
  };
  const onBeforeUnload = _ref11 => {
    let {
      channel
    } = _ref11;
    return function () {
      return channel.onBeforeUnload(...arguments);
    };
  };
  const setPageTitle = _ref12 => {
    let {
      channel
    } = _ref12;
    return pageTitle => {
      return channel.setPageTitle(pageTitle);
    };
  };
  const getLanguage = host => {
    let language = null;
    return async () => {
      var _observeStateResult;
      if (language) {
        return language;
      }
      let observeStateResult = null;
      language = await new Promise(resolve => {
        observeStateResult = observeState(host)((_, envState) => {
          resolve(envState.language);
        });
      });
      (_observeStateResult = observeStateResult) == null || _observeStateResult.disconnect();
      return language;
    };
  };
  const requestFeedback = _ref13 => {
    let {
      channel
    } = _ref13;
    return function () {
      return channel.requestFeedback(...arguments);
    };
  };
  const onLayerStateChange = _ref14 => {
    let {
      channel
    } = _ref14;
    return function () {
      const resultOrPromise = channel.onLayerStateChange(...arguments);
      const remove = () => Promise.resolve(resultOrPromise).then(h => h.remove());
      return {
        remove
      };
    };
  };
  const installApp = _ref15 => {
    let {
      channel
    } = _ref15;
    return channel.installApp;
  };
  const getWidget = _ref16 => {
    let {
      channel
    } = _ref16;
    return function () {
      if ('getWidget' in channel) {
        return channel.getWidget(...arguments);
      } else {
        throw new Error('Unsupported');
      }
    };
  };
  const getDashboardPlugins = _ref17 => {
    let {
      channel
    } = _ref17;
    return function () {
      if ('getDashboardPlugins' in channel) {
        return channel.getDashboardPlugins(...arguments);
      } else {
        throw new Error('Unsupported');
      }
    };
  };
  const getDashboardMenuPlugins = _ref18 => {
    let {
      channel
    } = _ref18;
    return function () {
      if ('getDashboardMenuPlugins' in channel) {
        return channel.getDashboardMenuPlugins(...arguments);
      } else {
        throw new Error('Unsupported');
      }
    };
  };
  const getSiteInfo = _ref19 => {
    let {
      channel
    } = _ref19;
    return channel.getSiteInfo;
  };
  return {
    showToast,
    observeState,
    navigate,
    navigateBack,
    openModal,
    closeModal,
    getAccessToken,
    getPageUrl,
    openMediaManager,
    addSitePlugin,
    onBeforeUnload,
    setPageTitle,
    getLanguage,
    requestFeedback,
    onLayerStateChange,
    installApp,
    getSiteInfo,
    getWidget,
    getDashboardPlugins,
    getDashboardMenuPlugins
  };
};
//# sourceMappingURL=sdk.js.map