import { OpenedChannel } from '@wix/communication-channel';
import type { AddSitePlugin } from './addSitePlugin';
import { GetAccessToken } from './auth';
import type { GetLanguage } from './language';
import { OpenMediaManager } from './mediaManager';
import { CloseModal, OpenModal, ProviderOpenModal } from './modal';
import { GetPageUrl, Navigate, NavigateBack } from './navigate';
import { ObserveState } from './observeState';
import { OnBeforeUnload } from './onBeforeUnload';
import { ShowToast } from './toast';
import type { RequestFeedback } from './requestFeedback';
import type { Host as SDKHost } from '@wix/sdk-types';
import { OnLayerStateChange } from './onLayerStateChange';
import { InstallApp } from './installApp';
import { GetWidget } from './widget';
import { GetDashboardMenuPlugins, GetDashboardPlugins } from './slots';
import { GetSiteInfo } from './getSiteInfo';
export * from './auth';
export * from './environment';
export * from './mediaManager';
export * from './modal';
export * from './navigate';
export * from './observeState';
export * from './onBeforeUnload';
export * from './serializable';
export * from './toast';
export * from './requestFeedback';
export * from './onLayerStateChange';
export * from './installApp';
export * from './getSiteInfo';
export type { GetLanguage, AddSitePlugin };
export type SetPageTitle = (pageTitle: string | null) => void;
export type PostMessage = (message: any, targetOrigin: string, transfer: Transferable[]) => void;
export type SDKOptions = {
    origin?: string;
    postMessage?: PostMessage;
    autoHeightUpdate?: boolean;
    autoHeightElement?: HTMLElement;
    fullUrl?: string;
};
export type Host = LocalHost | RemoteHost;
export type LocalHost = Omit<SDKHost, 'channel'> & {
    channel: Omit<ProviderAPI, 'updateHeight'>;
};
export type RemoteHost = Omit<SDKHost, 'channel'> & {
    channel: OpenedChannel<Omit<ProviderAPI, 'onBeforeUnload' | 'getSiteInfo' | 'getWidget' | 'getDashboardPlugins' | 'getDashboardMenuPlugins'>> & Pick<ProviderAPI, 'onBeforeUnload' | 'getSiteInfo'>;
    close: () => void;
};
export type DashboardProps = {
    host: Host;
};
export type CreateHost = (options?: SDKOptions) => RemoteHost;
export type SDK = {
    showToast: ShowToast;
    navigate: Navigate;
    navigateBack: NavigateBack;
    openModal: OpenModal;
    closeModal: CloseModal;
    getAccessToken: GetAccessToken;
    observeState: ObserveState;
    getPageUrl: GetPageUrl;
    openMediaManager: OpenMediaManager;
    addSitePlugin: AddSitePlugin;
    onBeforeUnload: OnBeforeUnload;
    setPageTitle: SetPageTitle;
    getLanguage: GetLanguage;
    requestFeedback: RequestFeedback;
    onLayerStateChange: OnLayerStateChange;
    installApp: InstallApp;
    getWidget: GetWidget;
    getDashboardPlugins: GetDashboardPlugins;
    getDashboardMenuPlugins: GetDashboardMenuPlugins;
    getSiteInfo: GetSiteInfo;
};
export type ProviderAPI = {
    showToast: ShowToast;
    navigate: Navigate;
    navigateBack: NavigateBack;
    updateHeight: (height: number) => void;
    observeState: ObserveState;
    closeModal: CloseModal;
    openModal: ProviderOpenModal;
    getAccessToken: GetAccessToken;
    getPageUrl: GetPageUrl;
    openMediaManager: OpenMediaManager;
    onBeforeUnload: OnBeforeUnload;
    setPageTitle: SetPageTitle;
    requestFeedback: RequestFeedback;
    onLayerStateChange: OnLayerStateChange;
    installApp: InstallApp;
    getWidget: GetWidget;
    getDashboardPlugins: GetDashboardPlugins;
    getDashboardMenuPlugins: GetDashboardMenuPlugins;
    getSiteInfo: GetSiteInfo;
};
//# sourceMappingURL=index.d.ts.map